==> thirdparty-service-biz-0.0.1-20161206.064205-1-sources.jar: cn/com/duiba/notifycenter/domain/NotifyQueueDO.java <==
package cn.com.duiba.notifycenter.domain;

import java.util.Date;

public class NotifyQueueDO {

	private Long id;
	private String relationType;
	private Long relationId;
	private Long appId;
	private Long consumerId;
	private Boolean result;
	private Date nextTime;
	private Integer times;
	private String error4developer;
	private String developerBizId;
	private String duibaOrderNum;
	private String partnerUserId;
	private Date gmtCreate;
	private Date gmtModified;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getRelationType() {
		return relationType;
	}

	public void setRelationType(String relationType) {
		this.relationType = relationType;
	}

	public Long getRelationId() {
		return relationId;
	}

	public void setRelationId(Long relationId) {
		this.relationId = relationId;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Long getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(Long consumerId) {
		this.consumerId = consumerId;
	}

	public Boolean getResult() {
		return result;
	}

	public void setResult(Boolean result) {
		this.result = result;
	}

	public Date getNextTime() {
		return nextTime;
	}

	public void setNextTime(Date nextTime) {
		this.nextTime = nextTime;
	}

	public Integer getTimes() {
		return times;
	}

	public void setTimes(Integer times) {
		this.times = times;
	}

	public String getError4developer() {
		return error4developer;
	}

	public void setError4developer(String error4developer) {
		this.error4developer = error4developer;
	}

	public String getDeveloperBizId() {
		return developerBizId;
	}

	public void setDeveloperBizId(String developerBizId) {
		this.developerBizId = developerBizId;
	}

	public String getDuibaOrderNum() {
		return duibaOrderNum;
	}

	public void setDuibaOrderNum(String duibaOrderNum) {
		this.duibaOrderNum = duibaOrderNum;
	}

	public String getPartnerUserId() {
		return partnerUserId;
	}

	public void setPartnerUserId(String partnerUserId) {
		this.partnerUserId = partnerUserId;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
}

==> thirdparty-service-biz-0.0.8-20171013.114628-1-sources.jar: cn/com/duiba/notifycenter/domain/NotifyQueueDO.java <==
package cn.com.duiba.notifycenter.domain;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.util.Date;

/**
 * 通知DO
 */
public class NotifyQueueDO {

	private Long id;
	private String relationType;
	private Long relationId;
	private Long appId;
	private Long consumerId;
	private Boolean result;
	private Date nextTime;
	private Integer times;
	private String error4developer;
	private String developerBizId;
	private String duibaOrderNum;
	private String partnerUserId;
	private String transfer;
	private Date gmtCreate;
	private Date gmtModified;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getRelationType() {
		return relationType;
	}

	public void setRelationType(String relationType) {
		this.relationType = relationType;
	}

	public Long getRelationId() {
		return relationId;
	}

	public void setRelationId(Long relationId) {
		this.relationId = relationId;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Long getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(Long consumerId) {
		this.consumerId = consumerId;
	}

	public Boolean getResult() {
		return result;
	}

	public void setResult(Boolean result) {
		this.result = result;
	}

	public Date getNextTime() {
		return nextTime;
	}

	public void setNextTime(Date nextTime) {
		this.nextTime = nextTime;
	}

	public Integer getTimes() {
		return times;
	}

	public void setTimes(Integer times) {
		this.times = times;
	}

	public String getError4developer() {
		return error4developer;
	}

	public void setError4developer(String error4developer) {
		this.error4developer = error4developer;
	}

	public String getDeveloperBizId() {
		return developerBizId;
	}

	public void setDeveloperBizId(String developerBizId) {
		this.developerBizId = developerBizId;
	}

	public String getDuibaOrderNum() {
		return duibaOrderNum;
	}

	public void setDuibaOrderNum(String duibaOrderNum) {
		this.duibaOrderNum = duibaOrderNum;
	}

	public String getPartnerUserId() {
		return partnerUserId;
	}

	public void setPartnerUserId(String partnerUserId) {
		this.partnerUserId = partnerUserId;
	}
	
	public String getTransfer() {
		return transfer;
	}

	public void setTransfer(String transfer) {
		this.transfer = transfer;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

	@Override
	public String toString() {
		return ToStringBuilder.reflectionToString(this);
	}
}
